@@ -70,6 +70,10 @@ class Graphics(Handler):
 
     def dialogTypes(self):
         return ['confirm', 'lineedit', 'multiline', 'generic']
+    
+    def getWidget(self, record):
+        if record['keyword'] in ['pushbutton']: return self.getSymbolContent(record)
+        else: return record['widget']
 
     class ClickableLineEdit(QLineEdit):
         clicked = Signal()
@@ -200,13 +204,13 @@ class Graphics(Handler):
             layoutRecord = self.getVariable(command['layout'])
             widget = command['widget']
             if widget == 'stretch':
-                layoutRecord['widget'].addStretch()
+                self.getWidget(layoutRecord).addStretch()
             elif widget == 'spacer':
-                layoutRecord['widget'].addSpacing(self.getRuntimeValue(command['size']))
+                self.getWidget(layoutRecord).addSpacing(self.getRuntimeValue(command['size']))
             else:
                 widgetRecord = self.getVariable(widget)
                 layoutRecord = self.getVariable(command['layout'])
-                widget = widgetRecord['widget']
+                widget = self.getWidget(widgetRecord)
                 layout = layoutRecord['widget']
                 stretch = 'stretch' in command
                 if widgetRecord['keyword'] == 'layout':
@@ -569,7 +573,6 @@ class Graphics(Handler):
             w = fm.horizontalAdvance('m') * self.getRuntimeValue(command['size']) + c.left()+c.right()
             pushbutton.setMaximumWidth(w)
         self.putSymbolValue(record, pushbutton)
-        record['widget'] = pushbutton
         return self.nextPC()
     
     def r_createCheckBox(self, command, record):
@@ -881,18 +884,21 @@ class Graphics(Handler):
         return False
     
     def r_on(self, command):
-        def run(widget):
-            print(f"Widget {widget} was clicked")
-            self.run(command['goto'])
+        def run(widget, record):
+            for i, w in enumerate(record['value']):
+                if w == widget:
+                    record['index'] = i
+                    self.run(command['goto'])
+                    return
 
         if command['type'] == 'tick':
             self.runOnTick = command['runOnTick']
         else:
             record = self.getVariable(command['name'])
-            widget = record['widget']
+            widget = self.getWidget(record)
             keyword = record['keyword']
             if keyword == 'pushbutton':
-                handler = partial(run, widget)
+                handler = partial(run, widget, record)
                 widget.clicked.connect(handler)
             elif keyword == 'combobox':
                 widget.currentIndexChanged.connect(lambda: self.run(command['goto']))
@@ -1164,19 +1170,23 @@ class Graphics(Handler):
                 elif flag == 'center': alignment |= Qt.AlignCenter
             widget.setAlignment(alignment)
         elif what == 'style':
-            widget = self.getVariable(command['name'])['widget']
+            record = self.getVariable(command['name'])
+            widget = self.getWidget(record)
             styles = self.getRuntimeValue(command['value'])
             widget.setStyleSheet(styles)
         elif what == 'color':
-            widget = self.getVariable(command['name'])['widget']
+            record = self.getVariable(command['name'])
+            widget = self.getWidget(record)
             color = self.getRuntimeValue(command['value'])
             widget.setStyleSheet(f"color: {color};")
         elif what == 'background-color':
-            widget = self.getVariable(command['name'])['widget']
+            record = self.getVariable(command['name'])
+            widget = self.getWidget(record)
             bg_color = self.getRuntimeValue(command['value'])
             widget.setStyleSheet(f"background-color: {bg_color};")
         elif what == 'listbox':
-            widget = self.getVariable(command['name'])['widget']
+            record = self.getVariable(command['name'])
+            widget = self.getWidget(record)
             value = self.getRuntimeValue(command['value'])
             widget.clear()
             widget.addItems(value)
@@ -1351,7 +1361,7 @@ class Graphics(Handler):
         symbolRecord = self.getVariable(symbolRecord['name'])
         keyword = symbolRecord['keyword']
         if keyword == 'pushbutton':
-            pushbutton = symbolRecord['widget']
+            pushbutton = self.getSymbolContent() # symbolRecord['widget']
             v = {}
             v['type'] = 'text'
             v['content'] = pushbutton.accessibleName()
